\name{coxph.hoa}
\alias{coxph.hoa}
\title{Test on a coefficient based on high-order asymptotics employing a reference censoring model}
\description{
Performs the hypothesis testing \eqn{H_0: \psi=value}{H0: psi=value}, computing the higher-order asymptotic
solution  \eqn{r^*}{r*}  from a parametric resampling based on a reference censoring model.
The function can also compute the  \eqn{r^*}{r*} statistic taking the risk sets as fixed. 
}
\usage{
coxph.hoa(coxph.obj, psi, ind.psi, R = 3000, fixed.risk.set = FALSE, tol = 10^-5)
}
\arguments{
  \item{coxph.obj}{
   an object produced by fitting a \acronym{PH} model with \code{coxph}. 
 }
  \item{psi}{ 
   the values of the parameter of interest under testing.
}
  \item{ind.psi}{
   the column index of the interest parameter covariate  in the design matrix. The latter can be obtained by
           \code{model.matrix(coxph.obj)[,-1]}.  
 }
  \item{R}{ 
   number of \acronym{MC} trials for computing the covariances required by  \eqn{r^*}{r*}. The default is  \code{3000}. 
 }
  \item{fixed.risk.set}{ 
    if \code{TRUE}, takes the risk sets as fixed. The default is \code{FALSE}.
 }
  \item{tol}{ 
   tolerance for considering \eqn{r=0}{r=0}. The default is \code{10^-5}.
 }
}
\details{
  The current version supports  only right-censoring without stratification when \code{fixed.risk.set=FALSE},
  and it implements uniform resampling from the risk set for the units to be censored.
  No check is made on  coxph.obj, and passing coxph objects created with left-censored data, interval data or counting process data will produce uncorrect results if  \code{fixed.risk.set=FALSE}.
}
\value{
  a list summarising the test 
  \item{wald }{ Wald statistic for testing \eqn{\psi}{psi}}
  \item{r.obs }{ observed value of \eqn{r}{r}}
  \item{NP, INF }{ terms of the \eqn{NP/INF} decomposition of the higher-order adjustment}
  \item{rs.obs }{ observed value of  \eqn{r^*}{r*}}
}

\references{Pierce, D.A, and Bellio, R. (2014). "Beyond first-order asymptotics for Cox regression". \emph{Bernoulli}, to appear.}

\author{Ruggero Bellio, Donald A. Pierce}

\examples{
library(survival)
data(veteran)
## Select celltype==smallcell
vet2<- veteran[veteran$celltype=="smallcell",]
## Model fit 
fit <- coxph(Surv(time,status) ~ age + trt + karno + diagtime + prior, data = vet2)
summary(fit)
## Testing treatment effect
obj <- coxph.hoa(fit, psi=0, ind.psi=2, R=3000)
## r-based right-sided P-value
(1 - pnorm(obj$r.obs))
## r*-based right-sided P-value
(1 - pnorm(obj$rs.obs))
## wald-type confidence intervals
confint(fit)
## Let us compute confidence intervals for psi by profiling
psi <- seq(-0.2, 1.5, l=20)
mat.ci <- matrix(0, nrow=20, ncol=2)
for(i in 1:20)
 { print(i)
   obj <- coxph.hoa(fit, psi=psi[i], ind.psi=2)
   mat.ci[i,] <- c(obj$r.obs, obj$rs.obs)
} 
obj.r <- smooth.spline(mat.ci[,1], psi, all.knots=TRUE)
obj.rs <- smooth.spline(mat.ci[,2], psi,  all.knots=TRUE)
## interval based on the profile partial likelihood
sort(predict(obj.r, c(qnorm(0.025), qnorm(0.975)))$y) 
## interval based on r*
sort(predict(obj.rs, c(qnorm(0.025), qnorm(0.975)))$y) 
}
\keyword{survival}

